@@ -12,7 +12,7 @@ from useragent_classifier.features_importances import FeatureImportance
 from useragent_classifier.graphical_explanation import run_server
 
 def read_data(ua_path: str) -> pd.DataFrame:
-    df = pd.read_csv(ua_path, header=None)
+    df = pd.read_csv(ua_path, header=None, sep="azrhuizehfiazhyufazghfai")
     df.columns = ["ua"]
     df = df.drop_duplicates(subset=["ua"], ignore_index=True)
     click.echo(f"Computing for {df.shape[0]} distinct User Agent Found")
